pub enum Token {
Number(f64),
Operator(Operation),
LeftParen,
RightParen,
}Expand description
Token types from lexical analysis
Variants
Number(f64)
Numeric literal
Operator(Operation)
Binary operator
LeftParen
Left parenthesis
RightParen
Right parenthesis
Implementations
Sourceimpl Token
impl Token
Sourcepub const fn is_operator(&self) -> bool
pub const fn is_operator(&self) -> bool
Returns true if this token is an operator
Sourcepub const fn is_left_paren(&self) -> bool
pub const fn is_left_paren(&self) -> bool
Returns true if this token is a left parenthesis
Sourcepub const fn is_right_paren(&self) -> bool
pub const fn is_right_paren(&self) -> bool
Returns true if this token is a right parenthesis